chicken_turtle_util.exceptions
==============================

.. automodule:: chicken_turtle_util.exceptions

.. autosummary::
   :nosignatures:

   InvalidOperationError
   UserException

.. autoexception:: InvalidOperationError 
.. autoexception:: UserException 
